@@ -878,6 +878,14 @@ class AppInstall(SimpleGladeApp):
                "cp", channelpath,
                apt_pkg.Config.FindDir("Dir::Etc::sourceparts")]
         subprocess.call(cmd)
+        # install the key as well
+        if os.path.exists(channelkey):
+            cmd = ["gksu",
+                   "--desktop",
+                   "/usr/share/applications/gnome-app-install.desktop",
+                   "--",
+                   "apt-key", "add",channelkey]
+            subprocess.call(cmd)
                 
     def enableComponent(self, component):
         """ Enables a component of the current distribution
